@@ -1,6 +1,6 @@
 from nautilus_librarian.domain.validate_filepaths import validate_filepath
 from nautilus_librarian.mods.dvc.domain.utils import (
-    extract_list_of_media_file_changes_from_dvc_diff_output,
+    extract_list_of_new_or_renamed_files_from_dvc_diff_output,
     get_new_filepath_if_is_a_renaming_dict,
 )
 from nautilus_librarian.typer.commands.workflows.actions.action_result import (
@@ -20,9 +20,7 @@ def validate_filepaths_action(dvc_diff):
             ResultCode.EXIT, [Message("No media library file changes found")]
         )
 
-    filepaths = extract_list_of_media_file_changes_from_dvc_diff_output(
-        dvc_diff, only_basename=False
-    )
+    filepaths = extract_list_of_new_or_renamed_files_from_dvc_diff_output(dvc_diff)
 
     messages = []
 
